@@ -63,237 +63,237 @@ bool EventHandler::eventFilter(TQObject*, TQEvent *e )
 	if (mp_thread == NULL)
 	{
 		emit ftp_error("mp_thread is NULL");
-		return TRUE;
+		return true;
 	}
 	else if (type == outlog) 
 	{   
 		TQString *line = static_cast<TQString*>(static_cast<TQCustomEvent*>(e)->data());
 		emit ftp_log(*line, true);
 		delete line;
-      return TRUE; 
+      return true; 
    }
 	else if (type == inlog) 
 	{   
 		TQString *line = static_cast<TQString*>(static_cast<TQCustomEvent*>(e)->data());
 		emit ftp_log(*line, false);
 		delete line;
-      return TRUE; 
+      return true; 
    }
 	else if (type == xfered) 
 	{   
 		xferpair* xp = static_cast<xferpair*>(static_cast<TQCustomEvent*>(e)->data());
 		emit ftp_xfered(xp->first, xp->second);
 		delete xp;
-      return TRUE; 
+      return true; 
    }
 	else if (type == finished) 
 	{   
 		emit ftp_finished();
-      return TRUE; 
+      return true; 
    }	
 	else if (type == connectionlost) 
 	{   
 		emit ftp_connectionlost();
-      return TRUE; 
+      return true; 
    }	
 	else if (type == connect_success) 
 	{   
 		emit ftp_connect(true);
-      return TRUE; 
+      return true; 
    } 
 	else if (type == connect_failure) 
 	{   
 		emit ftp_connect(false);
-      return TRUE; 
+      return true; 
    }
 	else if (type == misc_success) 
 	{   
 		emit ftp_misc(true);
-      return TRUE; 
+      return true; 
    } 
 	else if (type == misc_failure) 
 	{   
 		emit ftp_misc(false);
-      return TRUE; 
+      return true; 
    }
 	else if (type == login_success) 
 	{   
 		emit ftp_login(true);
-      return TRUE; 
+      return true; 
    } 
 	else if (type == login_failure) 
 	{   
 		emit ftp_login(false);
-      return TRUE; 
+      return true; 
    }
 	else if (type == quit_success) 
 	{   
 		emit ftp_quit(true);
-      return TRUE; 
+      return true; 
    } 
 	else if (type == quit_failure) 
 	{   
 		emit ftp_quit(false);
-      return TRUE; 
+      return true; 
    }
 	else if (type == authtls_success) 
 	{   
 		emit ftp_authtls(true);
-      return TRUE; 
+      return true; 
    } 
 	else if (type == authtls_failure) 
 	{   
 		emit ftp_authtls(false);
-      return TRUE; 
+      return true; 
    }
 	else if (type == pwd_success) 
 	{   
 		TQString *path = static_cast<TQString*>(static_cast<TQCustomEvent*>(e)->data());
 		emit ftp_pwd(true, *path);
 		delete path;
-      return TRUE; 
+      return true; 
    } 
 	else if (type == pwd_failure) 
 	{   
 		emit ftp_pwd(false, "");
-      return TRUE; 
+      return true; 
    }
 	else if (type == chdir_success) 
 	{   
 		emit ftp_chdir(true);
-      return TRUE; 
+      return true; 
    }
 	else if (type == chdir_failure) 
 	{   
 		emit ftp_chdir(false);
-      return TRUE; 
+      return true; 
    }
 	else if (type == transfer_success) 
 	{   
 		emit ftp_transfer(true);
-      return TRUE; 
+      return true; 
    }
 	else if (type == transfer_failure) 
 	{   
 		emit ftp_transfer(false);
-      return TRUE; 
+      return true; 
    }
 	else if (type == dir_success) 
 	{   
 		contentpair *content = static_cast<contentpair*>(static_cast<TQCustomEvent*>(e)->data());
 		emit ftp_dir(true, content->first, content->second);
-      return TRUE; 
+      return true; 
    }
 	else if (type == dir_failure) 
 	{   
 		contentpair *content = static_cast<contentpair*>(static_cast<TQCustomEvent*>(e)->data());
 		emit ftp_dir(false, content->first, content->second);
-      return TRUE; 
+      return true; 
    }
 	else if (type == scandir_success) 
 	{   
 		KbDirInfo *dir = static_cast<KbDirInfo*>(static_cast<TQCustomEvent*>(e)->data());
 		emit ftp_scandir(true, dir);
-      return TRUE; 
+      return true; 
    }
 	else if (type == scandir_failure) 
 	{   
 		emit ftp_scandir(false, NULL);
-      return TRUE; 
+      return true; 
    }
 	else if (type == rm_success) 
 	{   
 		emit ftp_rm(true);
-      return TRUE; 
+      return true; 
    }
 	else if (type == rm_failure) 
 	{   
 		emit ftp_rm(false);
-      return TRUE; 
+      return true; 
    }
 	else if (type == rmdir_success) 
 	{   
 		emit ftp_rmdir(true);
-      return TRUE; 
+      return true; 
    }
 	else if (type == rmdir_failure) 
 	{   
 		emit ftp_rmdir(false);
-      return TRUE; 
+      return true; 
    }
 	else if (type == encryptdata_success) 
 	{   
 		emit ftp_encryptdata(true);
-      return TRUE; 
+      return true; 
    }
 	else if (type == encryptdata_failure) 
 	{   
 		emit ftp_encryptdata(false);
-      return TRUE; 
+      return true; 
    }
 	else if (type == get_success) 
 	{   
 		emit ftp_get(true);
-      return TRUE; 
+      return true; 
    }
 	else if (type == get_failure) 
 	{   
 		emit ftp_get(false);
-      return TRUE; 
+      return true; 
    }
 	else if (type == mkdir_success) 
 	{   
 		emit ftp_mkdir(true);
-      return TRUE; 
+      return true; 
    }
 	else if (type == mkdir_failure) 
 	{   
 		emit ftp_mkdir(false);
-      return TRUE; 
+      return true; 
    }
 	else if (type == rename_success) 
 	{   
 		emit ftp_rename(true);
-      return TRUE; 
+      return true; 
    }
 	else if (type == rename_failure) 
 	{   
 		emit ftp_rename(false);
-      return TRUE; 
+      return true; 
    }
 	else if (type == raw_success) 
 	{   
 		emit ftp_raw(true);
-      return TRUE; 
+      return true; 
    }
 	else if (type == raw_failure) 
 	{   
 		emit ftp_raw(false);
-      return TRUE; 
+      return true; 
    }
 	else if (type == put_success) 
 	{   
 		emit ftp_put(true);
-      return TRUE; 
+      return true; 
    }
 	else if (type == put_failure) 
 	{   
 		emit ftp_put(false);
-      return TRUE; 
+      return true; 
    }
 	else if (type == fxp_success) 
 	{   
 		emit ftp_fxp(true);
-      return TRUE; 
+      return true; 
    }
 	else if (type == fxp_failure) 
 	{   
 		emit ftp_fxp(false);
-      return TRUE; 
+      return true; 
    }
 	else 
 	{
-      return FALSE;
+      return false;
   	}
 }
 
