@@ -381,7 +381,7 @@ void FtpSession::SLOT_CmdLine()
  		p->setWorkingDirectory(m_localworkingdir.absPath());
 		*p << TQStringList::split(" ", mp_cmdline->text());
 		connect(p, TQ_SIGNAL(processExited(TDEProcess*)), TQ_SLOT(SLOT_LocalProcessExited(TDEProcess*)));
-		if (p->start() == TRUE) mp_cmdline->setText("");
+		if (p->start()) mp_cmdline->setText("");
 	}
 }
 
