@@ -18,7 +18,7 @@
 #ifndef FILEITEM_H
 #define FILEITEM_H
 
-#include <ntqlistview.h>
+#include <tqlistview.h>
 #include "kbitem.h"
 
 class KbFileInfo;
