@@ -10,7 +10,7 @@
 //
 //
 
-#include <ntqcursor.h>
+#include <tqcursor.h>
 
 #include "kbstatustip.h"
 
