@@ -13,8 +13,8 @@
 
 #include <tdelocale.h>
 
-#include <ntqptrlist.h>
-#include <ntqevent.h>
+#include <tqptrlist.h>
+#include <tqevent.h>
 
 #include "kbtaskview.h"
 #include "kbfileinfo.h"
@@ -34,8 +34,8 @@ KbTaskView::KbTaskView(TQWidget *parent, const char *name)
 	setDragEnabled(true);
 	setAcceptDrops(true);
 		
-	//connect(this, SIGNAL(doubleClicked(TQListViewItem*, const TQPoint&, int)),
-	//	this, SLOT(SLOT_DoubleClicked(TQListViewItem*, const TQPoint&, int)));
+	//connect(this, TQ_SIGNAL(doubleClicked(TQListViewItem*, const TQPoint&, int)),
+	//	this, TQ_SLOT(SLOT_DoubleClicked(TQListViewItem*, const TQPoint&, int)));
 }
 
 KbTaskView::~KbTaskView()
